@@ -3,6 +3,7 @@
    Support for executable statements. */
 
 /*
+ * Copyright (c) 2009,2012 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 2004-2007 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1998-2003 by Internet Software Consortium
  *
@@ -22,12 +23,12 @@
  *   950 Charter Street
  *   Redwood City, CA 94063
  *   <info@isc.org>
- *   http://www.isc.org/
+ *   https://www.isc.org/
  *
  * This software has been written for Internet Systems Consortium
  * by Ted Lemon in cooperation with Vixie Enterprises and Nominum, Inc.
  * To learn more about Internet Systems Consortium, see
- * ``http://www.isc.org/''.  To learn more about Vixie Enterprises,
+ * ``https://www.isc.org/''.  To learn more about Vixie Enterprises,
  * see ``http://www.vix.com''.   To learn more about Nominum, Inc., see
  * ``http://www.nominum.com''.
  */
@@ -326,67 +327,68 @@ int execute_statements (result, packet, lease, client_state,
 
 		      case set_statement:
 		      case define_statement:
+			status = 1;
 			if (!scope) {
-				log_error ("set %s: no scope",
-					   r -> data.set.name);
+				log_error("set %s: no scope",
+					   r->data.set.name);
 				status = 0;
 				break;
 			}
 			if (!*scope) {
-			    if (!binding_scope_allocate (scope, MDL)) {
-				log_error ("set %s: can't allocate scope",
-					   r -> data.set.name);
+			    if (!binding_scope_allocate(scope, MDL)) {
+				log_error("set %s: can't allocate scope",
+					  r->data.set.name);
 				status = 0;
 				break;
 			    }
 			}
-			binding = find_binding (*scope, r -> data.set.name);
+			binding = find_binding(*scope, r->data.set.name);
 #if defined (DEBUG_EXPRESSIONS)
-			log_debug ("exec: set %s", r -> data.set.name);
+			log_debug("exec: set %s", r->data.set.name);
 #endif
-			if (!binding) {
-				binding = dmalloc (sizeof *binding, MDL);
-				if (binding) {
-				    memset (binding, 0, sizeof *binding);
-				    binding -> name =
-					    dmalloc (strlen
-						     (r -> data.set.name) + 1,
-						     MDL);
-				    if (binding -> name) {
-					strcpy (binding -> name,
-						r -> data.set.name);
-					binding -> next = (*scope) -> bindings;
-					(*scope) -> bindings = binding;
+			if (binding == NULL) {
+				binding = dmalloc(sizeof(*binding), MDL);
+				if (binding != NULL) {
+				    memset(binding, 0, sizeof(*binding));
+				    binding->name =
+					    dmalloc(strlen
+						    (r->data.set.name) + 1,
+						    MDL);
+				    if (binding->name != NULL) {
+					strcpy(binding->name, r->data.set.name);
+					binding->next = (*scope)->bindings;
+					(*scope)->bindings = binding;
 				    } else {
-					dfree (binding, MDL);
-					binding = (struct binding *)0;
+					dfree(binding, MDL);
+					binding = NULL;
 				    }
 				}
 			}
-			if (binding) {
-				if (binding -> value)
+			if (binding != NULL) {
+				if (binding->value != NULL)
 					binding_value_dereference
-						(&binding -> value, MDL);
-				if (r -> op == set_statement) {
+						(&binding->value, MDL);
+				if (r->op == set_statement) {
 					status = (evaluate_expression
-						  (&binding -> value, packet,
+						  (&binding->value, packet,
 						   lease, client_state,
 						   in_options, out_options,
-						   scope, r -> data.set.expr,
+						   scope, r->data.set.expr,
 						   MDL));
 				} else {
 				    if (!(binding_value_allocate
-					  (&binding -> value, MDL))) {
-					    dfree (binding, MDL);
-					    binding = (struct binding *)0;
+					  (&binding->value, MDL))) {
+					    dfree(binding, MDL);
+					    binding = NULL;
 				    }
-				    if (binding -> value) {
-				        binding -> value -> type =
-						binding_function;
-					(fundef_reference
-					 (&binding -> value -> value.fundef,
-					  r -> data.set.expr -> data.func,
-					  MDL));
+				    if ((binding != NULL) &&
+					(binding->value != NULL)) {
+					    binding->value->type =
+						    binding_function;
+					    (fundef_reference
+					     (&binding->value->value.fundef,
+					      r->data.set.expr->data.func,
+					      MDL));
 				    }
 				}
 			}
@@ -417,30 +419,31 @@ int execute_statements (result, packet, lease, client_state,
 
 		      case let_statement:
 #if defined (DEBUG_EXPRESSIONS)
-			log_debug ("exec: let %s", r -> data.let.name);
+			log_debug("exec: let %s", r->data.let.name);
 #endif
-			ns = (struct binding_scope *)0;
+			status = 0;
+			ns = NULL;
 			binding_scope_allocate (&ns, MDL);
 			e = r;
 
 		      next_let:
 			if (ns) {
-				binding = dmalloc (sizeof *binding, MDL);
-				memset (binding, 0, sizeof *binding);
+				binding = dmalloc(sizeof(*binding), MDL);
+				memset(binding, 0, sizeof(*binding));
 				if (!binding) {
 				   blb:
-				    binding_scope_dereference (&ns, MDL);
+				    binding_scope_dereference(&ns, MDL);
 				} else {
-				    binding -> name =
-					    dmalloc (strlen
-						     (e -> data.let.name + 1),
-						     MDL);
-				    if (binding -> name)
-					strcpy (binding -> name,
-						e -> data.let.name);
+				    binding->name =
+					    dmalloc(strlen
+						    (e->data.let.name + 1),
+						    MDL);
+				    if (binding->name)
+					strcpy(binding->name,
+					       e->data.let.name);
 				    else {
-					dfree (binding, MDL);
-					binding = (struct binding *)0;
+					dfree(binding, MDL);
+					binding = NULL;
 					goto blb;
 				    }
 				}
@@ -449,35 +452,35 @@ int execute_statements (result, packet, lease, client_state,
 
 			if (ns && binding) {
 				status = (evaluate_expression
-					  (&binding -> value, packet, lease,
+					  (&binding->value, packet, lease,
 					   client_state,
 					   in_options, out_options,
-					   scope, e -> data.set.expr, MDL));
-				binding -> next = ns -> bindings;
-				ns -> bindings = binding;
+					   scope, e->data.set.expr, MDL));
+				binding->next = ns->bindings;
+				ns->bindings = binding;
 			}
 
 #if defined (DEBUG_EXPRESSIONS)
-			log_debug ("exec: let %s%s", e -> data.let.name,
-				   (binding && status ? "" : "failed"));
+			log_debug("exec: let %s%s", e->data.let.name,
+				  (binding && status ? "" : "failed"));
 #endif
-			if (!e -> data.let.statements) {
-			} else if (e -> data.let.statements -> op ==
+			if (!e->data.let.statements) {
+			} else if (e->data.let.statements->op ==
 				   let_statement) {
-				e = e -> data.let.statements;
+				e = e->data.let.statements;
 				goto next_let;
 			} else if (ns) {
 				if (scope && *scope)
-				    	binding_scope_reference (&ns -> outer,
-								 *scope, MDL);
+				    	binding_scope_reference(&ns->outer,
+								*scope, MDL);
 				execute_statements
 				      (result, packet, lease,
 				       client_state,
 				       in_options, out_options,
-				       &ns, e -> data.let.statements);
+				       &ns, e->data.let.statements);
 			}
 			if (ns)
-				binding_scope_dereference (&ns, MDL);
+				binding_scope_dereference(&ns, MDL);
 			break;
 
 		      case log_statement:
